@@ -1,13 +1,14 @@
 /*
   Darts -- Double-ARray Trie System
 
-  $Id: darts.cpp 1575 2007-01-27 13:24:27Z taku $;
+  $Id: darts.cpp 1674 2008-03-22 11:21:34Z taku $;
 
   Copyright(C) 2001-2007 Taku Kudo <taku@chasen.org>
   All rights reserved.
 */
-#include <iostream>
 #include <darts.h>
+#include <iostream>
+#include <string>
 
 int main(int argc, char **argv) {
   if (argc < 2) {
@@ -23,8 +24,8 @@ int main(int argc, char **argv) {
     return -1;
   }
 
-  Darts::DoubleArray::result_pair_type  result_pair [1024];
-  Darts::DoubleArray::key_type          key    [1024];
+  Darts::DoubleArray::result_pair_type  result_pair[1024];
+  Darts::DoubleArray::key_type          key[1024];
 
   while (std::cin.getline(key, sizeof(key))) {
     size_t num = da.commonPrefixSearch(key, result_pair, sizeof(result_pair));
@@ -33,7 +34,8 @@ int main(int argc, char **argv) {
     } else {
       std::cout << key << ": found, num=" << num << " ";
       for (size_t i = 0; i < num; ++i) {
-	std::cout << " " << result_pair[i].value << ":" << result_pair[i].length;
+        std::cout << " " << result_pair[i].value
+                  << ":" << result_pair[i].length;
       }
       std::cout << std::endl;
     }
